@@ -91,15 +91,11 @@ impl Users {
         &self,
         status: crate::types::UsersStatus,
         role_id: &str,
-        page_number: &str,
         include_fields: crate::types::UsersIncludeFields,
     ) -> Result<Vec<crate::types::UsersResponse>> {
         let mut query = String::new();
         let mut query_args: Vec<String> = Default::default();
         query_args.push(format!("include_fields={}", include_fields));
-        if !page_number.is_empty() {
-            query_args.push(format!("page_number={}", page_number));
-        }
         if !role_id.is_empty() {
             query_args.push(format!("role_id={}", role_id));
         }
@@ -611,7 +607,7 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_settings_crate_types_domains(
+    pub async fn user_settings_domains(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
@@ -672,7 +668,7 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_settings_crate_types(
+    pub async fn user_settings(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
@@ -733,7 +729,7 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_settings_crate_types_meeting_security(
+    pub async fn user_settings_meeting_security(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
